@@ -1,4 +1,4 @@
-# Copyright 2020 Hewlett Packard Enterprise Development LP
+# Copyright 2020-2021 Hewlett Packard Enterprise Development LP
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -13,12 +13,18 @@
 # under the License.
 
 __author__ = 'HPE'
-
-from sushy.resources import base
+import collections
 
 
-class VirtualMediaConfigField(base.CompositeField):
-    """A class representing Virtual Media resource"""
+class VirtualMedia(object):
+    """Class that extends the functionality of Virtual Media"""
 
-    service_enabled = base.Field('ServiceEnabled')
-    """vmedia status"""
+    @staticmethod
+    def enable_vmedia(sushy_system, set_vmedia_state):
+        data = collections.defaultdict(dict)
+        data['VirtualMediaConfig']['ServiceEnabled'] = set_vmedia_state
+        sushy_system._conn.patch(sushy_system._path, data=data)
+
+    @staticmethod
+    def insert_vmedia_cifs(sushy_system, target_uri, data):
+        sushy_system._conn.post(target_uri, data=data)
